@@ -2,7 +2,7 @@ from __future__ import unicode_literals
 import datetime
 import copy
 
-VERSION = "0.0.10"
+VERSION = "0.0.11"
 
 
 class classproperty(object):
@@ -96,6 +96,8 @@ class Q(QMixin):
 
     def __init__(self, *args, **kwargs):
         self.conditions = kwargs
+        for arg in args:
+            self.conditions[arg] = None
 
     def __repr__(self,):
         return self._compile()
@@ -138,6 +140,9 @@ class Q(QMixin):
     def _process(self, compose_column, value):
         arr = compose_column.split("__")
         column = arr.pop(0)
+        if column == '':
+            column += "__" + arr.pop(0)
+
         try:
             lookup = arr.pop(0)
         except:
@@ -181,7 +186,10 @@ class Q(QMixin):
         if lookup in self.op_map.keys():
             return "{0}{1}{2}".format(column, self.op_map[lookup], self._get_value(value))
 
-        return "{0}{1}{2}".format(column, "=", self._get_value(value))
+        if value is not None:
+            return "{0}{1}{2}".format(column, "=", self._get_value(value))
+
+        return column
 
     def _compile(self,):
         filters = []
@@ -196,7 +204,8 @@ class Q(QMixin):
 
 class SQLQuery(object):
 
-    def __init__(self, table=None, sql_mode="MYSQL", sql=None):
+    def __init__(self, table=None, sql_mode="MYSQL", sql=None, **kwargs):
+        self.kwargs = kwargs
         self._table = table
         self.sql_mode = sql_mode
         self._values = ["*"]
@@ -257,7 +266,7 @@ class SQLQuery(object):
     def join(self, table, on="", how="inner join"):
         clone = self._clone()
         if on:
-            on = "ON " + on
+            on = "ON " + on.format(table=self._table)
             clone._joins.append("{how} {table} {on}".format(how=how, table=table, on=on))
         return clone
 
@@ -304,6 +313,9 @@ class SQLCompiler(object):
         conds = []
         for cond in self._order_by:
             order = ""
+            if cond is None:
+                continue
+
             column = cond
             try:
                 if cond[0] == "-":
@@ -337,22 +349,42 @@ class SQLCompiler(object):
             return str
 
     def get_top(self,):
-        if self._limits and self.sql_mode == "SQL_SERVER":
+        if self._limits and self.sql_mode == "SQL_SERVER" and not self._limits.start:
             return "TOP {0}".format(self._limits.stop)
 
     def get_sql_structure(self):
         if self._sql:
             if not self.has_filters():
                 return [self._sql]
-            table = u"(%s) as union1" % self._sql
+            table = "(%s) as union1" % self._sql
         else:
             table = self.get_table()
 
-        return ["SELECT", self.get_top(), self.get_columns(),
-                "FROM", table,
-                self.get_joins(), self.get_where(),
-                self.get_group_by(), self.get_order_by(),
-                self.get_limits()]
+        sql = ["SELECT", self.get_top(), self.get_columns(),
+               "FROM", table, "WITH (NOLOCK)",
+               self.get_joins(), self.get_where(),
+               self.get_group_by(), self.get_order_by(),
+               self.get_limits()]
+
+        if self.sql_mode == "SQL_SERVER" and self._limits and \
+           self._limits.start is not None and self._limits.stop is not None:
+            conds = []
+            if self._limits.start is not None:
+                conds.append("row_number > %s" % self._limits.start)
+
+            if self._limits.stop is not None:
+                conds.append("row_number <= %s" % self._limits.stop)
+
+            conds = " AND ".join(conds)
+            paginate = "ROW_NUMBER() OVER (%s) as row_number" % self.get_order_by()
+
+            return ["SELECT * FROM (", "SELECT", ",".join([paginate, self.get_columns()]),
+                    "FROM", table,
+                    self.get_joins(), self.get_where(),
+                    self.get_group_by(),
+                    self.get_limits(), ") as tbl_paginated WHERE ", conds]
+
+        return sql
 
     def _compile(self):
         return " ".join([unicode(item) for item in self.get_sql_structure() if item])
